# Filefisher

_A handy tool to find and parse file and folder names._

Filefisher is a python package that can create or find file and folder names according
to a pattern you define. This is handy if you have many folders or files that follow a
predefined naming structure.

## Documentation

Learn more about filefisher in its official documentation at [https://filefisher.readthedocs.io](https://filefisher.readthedocs.io)

## Get in touch

Don't hesitate to ask usage questions, report bugs, suggest features or view the source
code on GitHub under [mpytools/filefisher](https://github.com/mpytools/filefisher).

## License

filefisher is published under a MIT license.
